Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/browser/pdf.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/browser/pdf.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/browser/pdf.py	(revision 14181)
@@ -23,5 +23,5 @@
 from waeup.ikoba.browser.pdf import PDFCreator
 
-class SkeletonPDFCreator(PDFCreator):
+class UnibenPDFCreator(PDFCreator):
     """A utility to help with generating PDF docs.
     """
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/contracts.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/contracts.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/contracts.py	(revision 14181)
@@ -28,43 +28,43 @@
 from ikobacustom.uniben.interfaces import MessageFactory as _
 from ikobacustom.uniben.customers.interfaces import (
-    ISkeletonContract, ISkeletonContractEdit, ISkeletonContractProcess,
-    ISkeletonContractOfficialUse)
+    IUnibenContract, IUnibenContractEdit, IUnibenContractProcess,
+    IUnibenContractOfficialUse)
 
 
-class SkeletonContract(ContractBase):
+class UnibenContract(ContractBase):
     """This is a sample contract.
     """
 
     grok.implements(
-        ISkeletonContractProcess,
-        ISkeletonContract,
-        ISkeletonContractEdit,
+        IUnibenContractProcess,
+        IUnibenContract,
+        IUnibenContractEdit,
         ICustomerNavigation)
 
     contract_category = 'sample'
 
-    form_fields_interface = ISkeletonContract
+    form_fields_interface = IUnibenContract
 
-    edit_form_fields_interface = ISkeletonContractEdit
+    edit_form_fields_interface = IUnibenContractEdit
 
-    ou_form_fields_interface = ISkeletonContractOfficialUse
+    ou_form_fields_interface = IUnibenContractOfficialUse
 
-    check_docs_interface = ISkeletonContract
+    check_docs_interface = IUnibenContract
 
-SkeletonContract = attrs_to_fields(SkeletonContract)
+UnibenContract = attrs_to_fields(UnibenContract)
 
 
 # Contracts must be importable. So we might need a factory.
-class SkeletonContractFactory(grok.GlobalUtility):
+class UnibenContractFactory(grok.GlobalUtility):
     """A factory for contracts.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonContract')
+    grok.name(u'waeup.UnibenContract')
     title = u"Create a new contract.",
     description = u"This factory instantiates new sample contract instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonContract(*args, **kw)
+        return UnibenContract(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonContract)
+        return implementedBy(UnibenContract)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/customer.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/customer.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/customer.py	(revision 14181)
@@ -25,21 +25,21 @@
 from waeup.ikoba.customers.customer import Customer
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
-from ikobacustom.uniben.customers.interfaces import ISkeletonCustomer
+from ikobacustom.uniben.customers.interfaces import IUnibenCustomer
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonCustomer(Customer):
+class UnibenCustomer(Customer):
     """This is a customer container for the various objects
     owned by customers.
     """
-    grok.implements(ISkeletonCustomer, ICustomerNavigation)
-    grok.provides(ISkeletonCustomer)
+    grok.implements(IUnibenCustomer, ICustomerNavigation)
+    grok.provides(IUnibenCustomer)
 
-    form_fields_interface = ISkeletonCustomer
+    form_fields_interface = IUnibenCustomer
 
-SkeletonCustomer = attrs_to_fields(SkeletonCustomer)
+UnibenCustomer = attrs_to_fields(UnibenCustomer)
 
 
-class SkeletonCustomerFactory(grok.GlobalUtility):
+class UnibenCustomerFactory(grok.GlobalUtility):
     """A factory for customers.
     """
@@ -50,6 +50,6 @@
 
     def __call__(self, *args, **kw):
-        return SkeletonCustomer()
+        return UnibenCustomer()
 
     def getInterfaces(self):
-        return implementedBy(SkeletonCustomer)
+        return implementedBy(UnibenCustomer)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/documents.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/documents.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/documents.py	(revision 14181)
@@ -26,13 +26,13 @@
 from waeup.ikoba.customers.documents import CustomerDocumentBase
 from ikobacustom.uniben.interfaces import MessageFactory as _
-from ikobacustom.uniben.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.uniben.customers.interfaces import IUnibenCustomerDocument
 
 
-class SkeletonCustomerDocument(CustomerDocumentBase):
+class UnibenCustomerDocument(CustomerDocumentBase):
     """This is a sample customer document.
     """
 
-    grok.implements(ISkeletonCustomerDocument, ICustomerNavigation)
-    grok.provides(ISkeletonCustomerDocument)
+    grok.implements(IUnibenCustomerDocument, ICustomerNavigation)
+    grok.provides(IUnibenCustomerDocument)
 
     # Ikoba can store any number of files per Document object.
@@ -42,21 +42,21 @@
     filenames = ('sample',)
 
-    form_fields_interface = ISkeletonCustomerDocument
+    form_fields_interface = IUnibenCustomerDocument
 
-SkeletonCustomerDocument = attrs_to_fields(SkeletonCustomerDocument)
+UnibenCustomerDocument = attrs_to_fields(UnibenCustomerDocument)
 
 
 # Customer documents must be importable. So we need a factory.
-class SkeletonCustomerDocumentFactory(grok.GlobalUtility):
+class UnibenCustomerDocumentFactory(grok.GlobalUtility):
     """A factory for customer documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonCustomerDocument')
+    grok.name(u'waeup.UnibenCustomerDocument')
     title = u"Create a new document.",
     description = u"This factory instantiates new sample document instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonCustomerDocument(*args, **kw)
+        return UnibenCustomerDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonCustomerDocument)
+        return implementedBy(UnibenCustomerDocument)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/export.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/export.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/export.py	(revision 14181)
@@ -22,28 +22,28 @@
     CustomerExporter, CustomerDocumentExporterBase, ContractExporterBase)
 from ikobacustom.uniben.customers.interfaces import (
-    ISkeletonCustomer, ISkeletonCustomerDocument, ISkeletonContractProcess)
+    IUnibenCustomer, IUnibenCustomerDocument, IUnibenContractProcess)
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
-class SkeletonCustomerExporter(CustomerExporter):
+class UnibenCustomerExporter(CustomerExporter):
     """Exporter for Customers.
     """
-    iface = ISkeletonCustomer
-    title = _(u'Skeleton Customers')
+    iface = IUnibenCustomer
+    title = _(u'Uniben Customers')
 
 
-class SkeletonCustomerDocumentExporter(CustomerDocumentExporterBase):
+class UnibenCustomerDocumentExporter(CustomerDocumentExporterBase):
     """Exporter for documents.
     """
     grok.name('unibencustomerdocuments')
-    iface = ISkeletonCustomerDocument
-    title = _(u'Skeleton Customer Documents')
-    class_name = 'SkeletonCustomerDocument'
+    iface = IUnibenCustomerDocument
+    title = _(u'Uniben Customer Documents')
+    class_name = 'UnibenCustomerDocument'
 
 
-class SkeletonContractExporter(ContractExporterBase):
+class UnibenContractExporter(ContractExporterBase):
     """Exporter for Contract instances.
     """
     grok.name('unibencontracts')
-    iface = ISkeletonContractProcess
-    title = _(u'Skeleton Customer Contracts')
-    class_name = 'SkeletonContract'
+    iface = IUnibenContractProcess
+    title = _(u'Uniben Customer Contracts')
+    class_name = 'UnibenContract'
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/fileviewlets.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/fileviewlets.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/fileviewlets.py	(revision 14181)
@@ -23,5 +23,5 @@
     FileDisplay, FileUpload, Image)
 
-from ikobacustom.uniben.customers.documents import SkeletonCustomerDocument
+from ikobacustom.uniben.customers.documents import UnibenCustomerDocument
 
 from waeup.ikoba.customers.browser import (
@@ -39,5 +39,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(UnibenCustomerDocument)
     grok.view(DocumentManageFormPage)
     grok.require('waeup.manageCustomer')
@@ -61,5 +61,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(UnibenCustomerDocument)
     grok.require('waeup.viewCustomer')
     grok.view(DocumentDisplayFormPage)
@@ -74,5 +74,5 @@
     """
     grok.name('sample')
-    grok.context(SkeletonCustomerDocument)
+    grok.context(UnibenCustomerDocument)
     grok.require('waeup.viewCustomer')
     download_name = u'sample'
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/interfaces.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/interfaces.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/interfaces.py	(revision 14181)
@@ -27,5 +27,5 @@
 
 
-class ISkeletonCustomer(ICustomer):
+class IUnibenCustomer(ICustomer):
     """Representation of a customer.
 
@@ -35,5 +35,5 @@
 
 
-class ISkeletonCustomerDocument(ICustomerDocument):
+class IUnibenCustomerDocument(ICustomerDocument):
     """A customer document.
 
@@ -42,5 +42,5 @@
 # Customer contract interfaces
 
-class ISkeletonContract(IContract):
+class IUnibenContract(IContract):
     """A customer contract sample with document attached.
 
@@ -53,5 +53,5 @@
         )
 
-class ISkeletonContractOfficialUse(IIkobaObject):
+class IUnibenContractOfficialUse(IIkobaObject):
     """Interface for editing official use data.
 
@@ -63,5 +63,5 @@
         )
 
-class ISkeletonContractProcess(ISkeletonContract, ISkeletonContractOfficialUse):
+class IUnibenContractProcess(IUnibenContract, IUnibenContractOfficialUse):
     """Interface for processing contract data.
     """
@@ -75,5 +75,5 @@
         )
 
-class ISkeletonContractEdit(ISkeletonContract):
+class IUnibenContractEdit(IUnibenContract):
     """Interface for editing sample contract data by customers.
 
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_browser.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_browser.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_browser.py	(revision 14181)
@@ -31,11 +31,11 @@
 from waeup.ikoba.customers.tests.test_browser import CustomersFullSetup
 from ikobacustom.uniben.customers.export import (
-    SkeletonCustomerExporter,
-    SkeletonCustomerDocumentExporter,
-    SkeletonContractExporter)
+    UnibenCustomerExporter,
+    UnibenCustomerDocumentExporter,
+    UnibenContractExporter)
 from ikobacustom.uniben.customers.batching import (
-    SkeletonCustomerProcessor,
-    SkeletonCustomerDocumentProcessor,
-    SkeletonContractProcessor)
+    UnibenCustomerProcessor,
+    UnibenCustomerDocumentProcessor,
+    UnibenContractProcessor)
 from ikobacustom.uniben.testing import FunctionalLayer, samples_dir
 
@@ -61,8 +61,8 @@
         IWorkflowState(customer).setState('started')
         self.app['customers'].addCustomer(customer)
-        document = createObject(u'waeup.SkeletonCustomerDocument')
+        document = createObject(u'waeup.UnibenCustomerDocument')
         document.title = u'My first document'
         customer['documents'].addDocument(document)
-        contract = createObject(u'waeup.SkeletonContract')
+        contract = createObject(u'waeup.UnibenContract')
         contract.tc_dict = {'en':u'Hello World'}
         customer['contracts'].addContract(contract)
@@ -77,5 +77,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonCustomerExporter()
+        exporter = UnibenCustomerExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -85,5 +85,5 @@
             'K1000000,aa@aa.aa,Beate,Mueller,,,123,f,0,,,started,[]\r\n')
         # We can reimport the file ...
-        processor = SkeletonCustomerProcessor()
+        processor = UnibenCustomerProcessor()
         result = processor.doImport(
             self.outfile,
@@ -118,18 +118,18 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonCustomerDocumentExporter()
+        exporter = UnibenCustomerDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
         self.assertMatches(result,
             'class_name,document_id,history,state,title,user_id\r\n'
-            'SkeletonCustomerDocument,%s,'
+            'UnibenCustomerDocument,%s,'
             '[u\'2014-12-21 17:00:36 WAT - Document created by system\'],'
             'created,My first document,K1000000\r\n'
             % self.document.document_id)
         # We can reimport the file if we change the header (user_id -> customer_id)
-        processor = SkeletonCustomerDocumentProcessor()
+        processor = UnibenCustomerDocumentProcessor()
         open(self.outfile, 'wb').write(
             'customer_id,class_name,document_id,state,title\r\n'
-            'K1000000,SkeletonCustomerDocument,%s,started,My first title\r\n'
+            'K1000000,UnibenCustomerDocument,%s,started,My first title\r\n'
             % self.document.document_id)
         result = processor.doImport(
@@ -162,5 +162,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonContractExporter()
+        exporter = UnibenContractExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -169,15 +169,15 @@
             'fee_based,history,last_product_id,product_object,product_options,'
             'state,tc_dict,title,user_id,valid_from,valid_to\r\n'
-            'SkeletonContract,,sample,%s,,0,'
+            'UnibenContract,,sample,%s,,0,'
             '[u\'2014-12-21 22:26:00 WAT - Contract created by system\']'
             ',,,[],created,{\'en\': u\'Hello World\'},,K1000000,,\r\n'
             % self.contract.contract_id)
         # We can reimport the file if we change the header (user_id -> customer_id)
-        processor = SkeletonContractProcessor()
+        processor = UnibenContractProcessor()
         open(self.outfile, 'wb').write(
             'class_name,contract_category,contract_id,document_object,'
             'history,last_product_id,product_object,product_options,'
             'state,tc_dict,title,user_id\r\n'
-            'SkeletonContract,sample,%s,,'
+            'UnibenContract,sample,%s,,'
             '[u\'2014-12-21 22:26:00 WAT - Contract created by system\']'
             ',,,[],created,{\'en\': u\'Hello World\'},,K1000000\r\n'
@@ -221,6 +221,6 @@
     def setup_customizable_params(self):
         self._contract_category = u'sample'
-        self._document_factory = 'waeup.SkeletonCustomerDocument'
-        self._contract_factory = 'waeup.SkeletonContract'
+        self._document_factory = 'waeup.UnibenCustomerDocument'
+        self._contract_factory = 'waeup.UnibenContract'
         return
 
@@ -304,6 +304,6 @@
     def setup_customizable_params(self):
         self._contract_category = u'sample'
-        self._document_factory = 'waeup.SkeletonCustomerDocument'
-        self._contract_factory = 'waeup.SkeletonContract'
+        self._document_factory = 'waeup.UnibenCustomerDocument'
+        self._contract_factory = 'waeup.UnibenContract'
         return
 
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_contract.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_contract.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_contract.py	(revision 14181)
@@ -29,6 +29,6 @@
 
 from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.uniben.customers.contracts import SkeletonContract
-from ikobacustom.uniben.customers.interfaces import ISkeletonContract
+from ikobacustom.uniben.customers.contracts import UnibenContract
+from ikobacustom.uniben.customers.interfaces import IUnibenContract
 
 
@@ -38,17 +38,17 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonContract, SkeletonContract)
-        verify.verifyClass(ICustomerNavigation, SkeletonContract)
-        verify.verifyObject(ISkeletonContract, SkeletonContract())
-        verify.verifyObject(ICustomerNavigation, SkeletonContract())
+        verify.verifyClass(IUnibenContract, UnibenContract)
+        verify.verifyClass(ICustomerNavigation, UnibenContract)
+        verify.verifyObject(IUnibenContract, UnibenContract())
+        verify.verifyObject(ICustomerNavigation, UnibenContract())
         return
 
     def test_addContract(self):
         container = ContractsContainer()
-        contract = createObject(u'waeup.SkeletonContract')
+        contract = createObject(u'waeup.UnibenContract')
         id = contract.contract_id
         container.addContract(contract)
         self.assertEqual(container[id], contract)
         self.assertRaises(TypeError, container.addContract, object())
-        self.assertEqual(contract.class_name, 'SkeletonContract')
+        self.assertEqual(contract.class_name, 'UnibenContract')
         return
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_customer.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_customer.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_customer.py	(revision 14181)
@@ -31,13 +31,13 @@
 
 from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.uniben.customers.customer import SkeletonCustomer
-from ikobacustom.uniben.customers.interfaces import ISkeletonCustomer
+from ikobacustom.uniben.customers.customer import UnibenCustomer
+from ikobacustom.uniben.customers.interfaces import IUnibenCustomer
 
-class SkeletonCustomerTestCase(FunctionalTestCase):
+class UnibenCustomerTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
 
     def setUp(self):
-        super(SkeletonCustomerTestCase, self).setUp()
+        super(UnibenCustomerTestCase, self).setUp()
 
         # Prepopulate ZODB
@@ -52,13 +52,13 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonCustomer, SkeletonCustomer)
-        verify.verifyClass(ICustomerNavigation, SkeletonCustomer)
-        verify.verifyObject(ISkeletonCustomer, SkeletonCustomer())
-        verify.verifyObject(ICustomerNavigation, SkeletonCustomer())
+        verify.verifyClass(IUnibenCustomer, UnibenCustomer)
+        verify.verifyClass(ICustomerNavigation, UnibenCustomer)
+        verify.verifyObject(IUnibenCustomer, UnibenCustomer())
+        verify.verifyObject(ICustomerNavigation, UnibenCustomer())
         return
 
-    def test_addSkeletonCustomer(self):
+    def test_addUnibenCustomer(self):
         customer = createObject(u'waeup.Customer')
-        verify.verifyObject(ISkeletonCustomer, customer)
+        verify.verifyObject(IUnibenCustomer, customer)
         self.app['customers'].addCustomer(customer)
         self.assertEqual(customer.customer_id, 'K1000000')
@@ -68,4 +68,4 @@
     def tearDown(self):
         shutil.rmtree(self.dc_root)
-        super(SkeletonCustomerTestCase, self).tearDown()
+        super(UnibenCustomerTestCase, self).tearDown()
         return
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_document.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_document.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_document.py	(revision 14181)
@@ -29,6 +29,6 @@
 
 from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.uniben.customers.documents import SkeletonCustomerDocument
-from ikobacustom.uniben.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.uniben.customers.documents import UnibenCustomerDocument
+from ikobacustom.uniben.customers.interfaces import IUnibenCustomerDocument
 
 
@@ -38,17 +38,17 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonCustomerDocument, SkeletonCustomerDocument)
-        verify.verifyClass(ICustomerNavigation, SkeletonCustomerDocument)
-        verify.verifyObject(ISkeletonCustomerDocument, SkeletonCustomerDocument())
-        verify.verifyObject(ICustomerNavigation, SkeletonCustomerDocument())
+        verify.verifyClass(IUnibenCustomerDocument, UnibenCustomerDocument)
+        verify.verifyClass(ICustomerNavigation, UnibenCustomerDocument)
+        verify.verifyObject(IUnibenCustomerDocument, UnibenCustomerDocument())
+        verify.verifyObject(ICustomerNavigation, UnibenCustomerDocument())
         return
 
     def test_addDocument(self):
         container = CustomerDocumentsContainer()
-        document = createObject(u'waeup.SkeletonCustomerDocument')
+        document = createObject(u'waeup.UnibenCustomerDocument')
         id = document.document_id
         container.addDocument(document)
         self.assertEqual(container[id], document)
         self.assertRaises(TypeError, container.addDocument, object())
-        self.assertEqual(document.class_name, 'SkeletonCustomerDocument')
+        self.assertEqual(document.class_name, 'UnibenCustomerDocument')
         return
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/utils.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/utils.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/utils.py	(revision 14181)
@@ -27,5 +27,5 @@
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
-class SkeletonCustomersUtils(CustomersUtils):
+class UnibenCustomersUtils(CustomersUtils):
     """A collection of methods subject to customization.
     """
@@ -47,5 +47,5 @@
         #'CustomerPDFDocument': _('PDF Document'),
 
-        'SkeletonCustomerDocument': _('Skeleton Document'),
+        'UnibenCustomerDocument': _('Uniben Document'),
         }
 
@@ -53,5 +53,5 @@
         #'SampleContract': _('Sample Contract'),
 
-        'SkeletonContract': _('Skeleton Contract'),
+        'UnibenContract': _('Uniben Contract'),
         }
 
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py	(revision 14181)
@@ -2,7 +2,7 @@
 """
 # Make this a package.
-from ikobacustom.uniben.documents.document import SkeletonDocument
+from ikobacustom.uniben.documents.document import UnibenDocument
 
 __all__ = [
-    'SkeletonDocument',
+    'UnibenDocument',
     ]
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py	(revision 14181)
@@ -24,30 +24,30 @@
 from waeup.ikoba.utils.helpers import attrs_to_fields
 from waeup.ikoba.documents.document import PublicDocumentBase
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonDocument(PublicDocumentBase):
+class UnibenDocument(PublicDocumentBase):
     """This is a document.
     """
-    grok.implements(ISkeletonDocument)
-    grok.provides(ISkeletonDocument)
+    grok.implements(IUnibenDocument)
+    grok.provides(IUnibenDocument)
 
-    form_fields_interface = ISkeletonDocument
+    form_fields_interface = IUnibenDocument
 
-SkeletonDocument = attrs_to_fields(SkeletonDocument)
+UnibenDocument = attrs_to_fields(UnibenDocument)
 
 
-class SkeletonDocumentFactory(grok.GlobalUtility):
+class UnibenDocumentFactory(grok.GlobalUtility):
     """A factory for documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonDocument')
+    grok.name(u'waeup.UnibenDocument')
     title = u"Create a new document.",
     description = u"This factory instantiates new uniben documents."
 
     def __call__(self, *args, **kw):
-        return SkeletonDocument(*args, **kw)
+        return UnibenDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonDocument)
+        return implementedBy(UnibenDocument)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py	(revision 14181)
@@ -20,13 +20,13 @@
 import grok
 from waeup.ikoba.documents.export import DocumentExporterBase
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentExporter(DocumentExporterBase):
+class UnibenDocumentExporter(DocumentExporterBase):
     """Exporter for documents.
     """
     grok.name('unibendocuments')
-    iface = ISkeletonDocument
-    class_name = 'SkeletonDocument'
-    title = _(u'Skeleton Documents')
+    iface = IUnibenDocument
+    class_name = 'UnibenDocument'
+    title = _(u'Uniben Documents')
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py	(revision 14181)
@@ -20,5 +20,5 @@
 
 
-class ISkeletonDocument(IPublicDocument):
+class IUnibenDocument(IPublicDocument):
     """A representation of a uniben document.
 
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py	(revision 14181)
@@ -27,7 +27,7 @@
 from zope.interface.verify import verifyObject, verifyClass
 from waeup.ikoba.documents.tests.test_batching import DocumentImportExportSetup
-from ikobacustom.uniben.documents.document import SkeletonDocument
-from ikobacustom.uniben.documents.export import SkeletonDocumentExporter
-from ikobacustom.uniben.documents.batching import SkeletonDocumentProcessor
+from ikobacustom.uniben.documents.document import UnibenDocument
+from ikobacustom.uniben.documents.export import UnibenDocumentExporter
+from ikobacustom.uniben.documents.batching import UnibenDocumentProcessor
 from ikobacustom.uniben.testing import FunctionalLayer
 
@@ -38,5 +38,5 @@
 
     def setup_for_export(self):
-        document = SkeletonDocument()
+        document = UnibenDocument()
         document.document_id = u'DOC1'
         document.title = u'My first document'
@@ -49,5 +49,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonDocumentExporter()
+        exporter = UnibenDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -55,9 +55,9 @@
             'class_name,description,document_id,history,state,title,'
             'users_with_local_roles\r\n'
-            'SkeletonDocument,,DOC1,'
+            'UnibenDocument,,DOC1,'
             '[u\'2014-12-21 23:27:15 WAT - Document created by system\'],'
             'created,My first document,[]\r\n')
         # We can import the same file.
-        processor = SkeletonDocumentProcessor()
+        processor = UnibenDocumentProcessor()
         result = processor.doImport(
             self.outfile,
@@ -79,5 +79,5 @@
         self.assertEqual(num_fail,0)
         # We can import the same file in update mode.
-        processor = SkeletonDocumentProcessor()
+        processor = UnibenDocumentProcessor()
         result = processor.doImport(
             self.outfile,
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py	(revision 14181)
@@ -24,8 +24,8 @@
 
 from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.uniben.documents.document import SkeletonDocument
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.document import UnibenDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 
-class SkeletonDocumentTestCase(FunctionalTestCase):
+class UnibenDocumentTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
@@ -35,15 +35,15 @@
         self.assertTrue(
             verifyClass(
-                ISkeletonDocument, SkeletonDocument)
+                IUnibenDocument, UnibenDocument)
             )
         self.assertTrue(
             verifyObject(
-                ISkeletonDocument, SkeletonDocument())
+                IUnibenDocument, UnibenDocument())
             )
         return
 
-    def test_addSkeletonDocument(self):
+    def test_addUnibenDocument(self):
         container = DocumentsContainer()
-        document = createObject(u'waeup.SkeletonDocument')
+        document = createObject(u'waeup.UnibenDocument')
         document.document_id = u'DOC1'
         container.addDocument(document)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py	(revision 14181)
@@ -22,5 +22,5 @@
 
 
-class SkeletonDocumentsUtils(DocumentsUtils):
+class UnibenDocumentsUtils(DocumentsUtils):
     """A collection of methods subject to customization.
     """
@@ -30,5 +30,5 @@
         'HTMLDocument': _('HTML Document'),
         'RESTDocument': _('REST Document'),
-        'SkeletonDocument': _('Skeleton Document'),
+        'UnibenDocument': _('Uniben Document'),
         }
 
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/__init__.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/__init__.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/__init__.py	(revision 14181)
@@ -2,7 +2,7 @@
 """
 # Make this a package.
-from ikobacustom.uniben.products.product import SkeletonProduct
+from ikobacustom.uniben.products.product import UnibenProduct
 
 __all__ = [
-    'SkeletonProduct',
+    'UnibenProduct',
     ]
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/batching.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/batching.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/batching.py	(revision 14181)
@@ -20,11 +20,11 @@
 import grok
 from waeup.ikoba.products.batching import ProductProcessor
-from ikobacustom.uniben.products.interfaces import ISkeletonProduct
+from ikobacustom.uniben.products.interfaces import IUnibenProduct
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
-class SkeletonProductProcessor(ProductProcessor):
+class UnibenProductProcessor(ProductProcessor):
 
-    iface = ISkeletonProduct
-    name = _('Skeleton Product Processor')
+    iface = IUnibenProduct
+    name = _('Uniben Product Processor')
     util_name = 'unibenproductprocessor'
     grok.name(util_name)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/export.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/export.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/export.py	(revision 14181)
@@ -21,15 +21,15 @@
 from waeup.ikoba.utils.helpers import iface_names
 from waeup.ikoba.products.export import ProductExporter
-from ikobacustom.uniben.products.interfaces import ISkeletonProduct
+from ikobacustom.uniben.products.interfaces import IUnibenProduct
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonProductExporter(ProductExporter):
+class UnibenProductExporter(ProductExporter):
     """Exporter for products.
     """
 
-    fields = tuple(sorted(iface_names(ISkeletonProduct))) + (
+    fields = tuple(sorted(iface_names(IUnibenProduct))) + (
         'users_with_local_roles',)
 
     #: The title under which this exporter will be displayed
-    #title = _(u'Skeleton Products')
+    #title = _(u'Uniben Products')
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/interfaces.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/interfaces.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/interfaces.py	(revision 14181)
@@ -20,5 +20,5 @@
 
 
-class ISkeletonProduct(IProduct):
+class IUnibenProduct(IProduct):
     """A representation of a uniben product.
 
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/product.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/product.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/product.py	(revision 14181)
@@ -24,20 +24,20 @@
 from waeup.ikoba.utils.helpers import attrs_to_fields
 from waeup.ikoba.products.product import Product
-from ikobacustom.uniben.products.interfaces import ISkeletonProduct
+from ikobacustom.uniben.products.interfaces import IUnibenProduct
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonProduct(Product):
+class UnibenProduct(Product):
     """This is a product.
     """
-    grok.implements(ISkeletonProduct)
-    grok.provides(ISkeletonProduct)
+    grok.implements(IUnibenProduct)
+    grok.provides(IUnibenProduct)
 
-    form_fields_interface = ISkeletonProduct
+    form_fields_interface = IUnibenProduct
 
-SkeletonProduct = attrs_to_fields(SkeletonProduct)
+UnibenProduct = attrs_to_fields(UnibenProduct)
 
 
-class SkeletonProductFactory(grok.GlobalUtility):
+class UnibenProductFactory(grok.GlobalUtility):
     """A factory for products.
     """
@@ -48,6 +48,6 @@
 
     def __call__(self, *args, **kw):
-        return SkeletonProduct(*args, **kw)
+        return UnibenProduct(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonProduct)
+        return implementedBy(UnibenProduct)
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/tests/test_browser.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/tests/test_browser.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/tests/test_browser.py	(revision 14181)
@@ -27,7 +27,7 @@
 from zope.interface.verify import verifyObject, verifyClass
 from waeup.ikoba.products.tests.test_batching import ProductImportExportSetup
-from ikobacustom.uniben.products.product import SkeletonProduct
-from ikobacustom.uniben.products.export import SkeletonProductExporter
-from ikobacustom.uniben.products.batching import SkeletonProductProcessor
+from ikobacustom.uniben.products.product import UnibenProduct
+from ikobacustom.uniben.products.export import UnibenProductExporter
+from ikobacustom.uniben.products.batching import UnibenProductProcessor
 from ikobacustom.uniben.testing import FunctionalLayer
 
@@ -38,5 +38,5 @@
 
     def setup_for_export(self):
-        product = SkeletonProduct()
+        product = UnibenProduct()
         product.product_id = u'SAM'
         product.contract_category = u'sample'
@@ -50,5 +50,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonProductExporter()
+        exporter = UnibenProductExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -59,5 +59,5 @@
             'sample,,,[],SAM,,Unnamed,2015-12-04#,,[]\r\n')
         # We can import the same file.
-        processor = SkeletonProductProcessor()
+        processor = UnibenProductProcessor()
         result = processor.doImport(
             self.outfile,
@@ -81,5 +81,5 @@
         self.assertEqual(num_fail,0)
         # We can import the same file in update mode.
-        processor = SkeletonProductProcessor()
+        processor = UnibenProductProcessor()
         result = processor.doImport(
             self.outfile,
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/tests/test_product.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/tests/test_product.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/products/tests/test_product.py	(revision 14181)
@@ -25,8 +25,8 @@
 
 from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.uniben.products.product import SkeletonProduct
-from ikobacustom.uniben.products.interfaces import ISkeletonProduct
+from ikobacustom.uniben.products.product import UnibenProduct
+from ikobacustom.uniben.products.interfaces import IUnibenProduct
 
-class SkeletonProductTestCase(FunctionalTestCase):
+class UnibenProductTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
@@ -36,13 +36,13 @@
         self.assertTrue(
             verifyClass(
-                ISkeletonProduct, SkeletonProduct)
+                IUnibenProduct, UnibenProduct)
             )
         self.assertTrue(
             verifyObject(
-                ISkeletonProduct, SkeletonProduct())
+                IUnibenProduct, UnibenProduct())
             )
         return
 
-    def test_addSkeletonProduct(self):
+    def test_addUnibenProduct(self):
         container = ProductsContainer()
         product = createObject(u'waeup.Product')
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/utils/utils.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/utils/utils.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/utils/utils.py	(revision 14181)
@@ -33,5 +33,5 @@
     ]
 
-class SkeletonIkobaUtils(IkobaUtils):
+class UnibenIkobaUtils(IkobaUtils):
     """A collection of methods subject to customization.
     """

Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/batching.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/batching.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/batching.py	(revision 14181)
@@ -23,34 +23,34 @@
     CustomerDocumentProcessorBase, ContractProcessorBase)
 from ikobacustom.uniben.customers.interfaces import (
-    ISkeletonCustomer,
-    ISkeletonCustomerDocument, ISkeletonContract)
+    IUnibenCustomer,
+    IUnibenCustomerDocument, IUnibenContract)
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonCustomerProcessor(CustomerProcessor):
+class UnibenCustomerProcessor(CustomerProcessor):
     """A batch processor for ICustomer objects.
     """
     util_name = 'unibencustomerprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Processor')
-    iface = ISkeletonCustomer
+    name = _('Uniben Customer Processor')
+    iface = IUnibenCustomer
 
 
-class SkeletonCustomerDocumentProcessor(CustomerDocumentProcessorBase):
-    """A batch processor for ISkeletonCustomerDocument objects.
+class UnibenCustomerDocumentProcessor(CustomerDocumentProcessorBase):
+    """A batch processor for IUnibenCustomerDocument objects.
     """
     util_name = 'unibencustomerdocumentprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Document Processor')
-    iface = ISkeletonCustomerDocument
-    factory_name = 'waeup.SkeletonCustomerDocument'
+    name = _('Uniben Customer Document Processor')
+    iface = IUnibenCustomerDocument
+    factory_name = 'waeup.UnibenCustomerDocument'
 
 
-class SkeletonContractProcessor(ContractProcessorBase):
-    """A batch processor for ISkeletonContract objects.
+class UnibenContractProcessor(ContractProcessorBase):
+    """A batch processor for IUnibenContract objects.
     """
     util_name = 'unibencontractprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Contract Processor')
-    iface = ISkeletonContract
-    factory_name = 'waeup.SkeletonContract'
+    name = _('Uniben Customer Contract Processor')
+    iface = IUnibenContract
+    factory_name = 'waeup.UnibenContract'
Index: /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py
===================================================================
--- /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py	(revision 14180)
+++ /main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py	(revision 14181)
@@ -20,16 +20,16 @@
 import grok
 from waeup.ikoba.documents.batching import DocumentProcessorBase
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentProcessor(DocumentProcessorBase):
-    """A batch processor for ISkeletonDocument objects.
+class UnibenDocumentProcessor(DocumentProcessorBase):
+    """A batch processor for IUnibenDocument objects.
     """
     util_name = 'unibendocumentprocessor'
     grok.name(util_name)
 
-    name = _('Skeleton Document Processor')
-    iface = ISkeletonDocument
+    name = _('Uniben Document Processor')
+    iface = IUnibenDocument
 
-    factory_name = 'waeup.SkeletonDocument'
+    factory_name = 'waeup.UnibenDocument'